<?php

namespace Drupal\site_assistant;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultAllowed;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Access\AccessResultReasonInterface;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for the assistant related entities (.
 *
 * @see \Drupal\site_assistant\Entity\Assistant.
 */
class AssistantAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account): AccessResultReasonInterface|AccessResult|AccessResultAllowed|AccessResultInterface {
    return match ($operation) {
      'view' => AccessResult::allowedIfHasPermissions($account, [
        'view assistant content',
        'administer site_assistant',
      ], 'OR'),
      'edit' => AccessResult::allowedIfHasPermissions($account, [
        'edit assistant content',
        'administer site_assistant',
      ], 'OR'),
      'delete' => AccessResult::allowedIfHasPermissions($account, [
        'delete assistant content',
        'administer site_assistant',
      ], 'OR'),
      default => AccessResult::allowed(),
    };
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL): AccessResultReasonInterface|AccessResult|AccessResultInterface {
    return AccessResult::allowedIfHasPermissions($account, [
      'add assistant content',
      'administer site_assistant',
    ], 'OR');
  }

}
