<?php

namespace Drupal\site_assistant;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of assist list entry type entities.
 *
 * @see \Drupal\site_assistant\Entity\AssistantListEntryType
 */
class AssistantListEntryTypeListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header = [];
    $header['title'] = $this->t('Name');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    $row = [];
    $row['title'] = [
      'data' => $entity->label(),
      'class' => ['menu-label'],
    ];
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function render(): array {
    $build = parent::render();
    $build['table']['#empty'] = $this->t('No site assistant entry types available. <a href=":link">Add assistant entry type</a>.', [
      ':link' => Url::fromRoute('entity.assistant_list_entry_type.add_form')
        ->toString(),
    ]);
    return $build;
  }

}
